==> knative-model-5.3.0-sources.jar: io/fabric8/knative/eventing/contrib/couchdb/v1alpha1/CouchDbSourceSpecFluent.java <==
package io.fabric8.knative.eventing.contrib.couchdb.v1alpha1;

import io.fabric8.knative.internal.pkg.apis.duck.v1.Destination;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationFluent;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface CouchDbSourceSpecFluent<A extends CouchDbSourceSpecFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildCredentials instead.
 * @return The buildable object.
 */
@Deprecated public ObjectReference getCredentials();
    public ObjectReference buildCredentials();
    public A withCredentials(ObjectReference credentials);
    public Boolean hasCredentials();
    public CouchDbSourceSpecFluent.CredentialsNested<A> withNewCredentials();
    public CouchDbSourceSpecFluent.CredentialsNested<A> withNewCredentialsLike(ObjectReference item);
    public CouchDbSourceSpecFluent.CredentialsNested<A> editCredentials();
    public CouchDbSourceSpecFluent.CredentialsNested<A> editOrNewCredentials();
    public CouchDbSourceSpecFluent.CredentialsNested<A> editOrNewCredentialsLike(ObjectReference item);
    public String getDatabase();
    public A withDatabase(String database);
    public Boolean hasDatabase();
    public A withNewDatabase(StringBuilder arg1);
    public A withNewDatabase(int[] arg1,int arg2,int arg3);
    public A withNewDatabase(char[] arg1);
    public A withNewDatabase(StringBuffer arg1);
    public A withNewDatabase(byte[] arg1,int arg2);
    public A withNewDatabase(byte[] arg1);
    public A withNewDatabase(char[] arg1,int arg2,int arg3);
    public A withNewDatabase(byte[] arg1,int arg2,int arg3);
    public A withNewDatabase(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewDatabase(String arg1);
    public String getFeed();
    public A withFeed(String feed);
    public Boolean hasFeed();
    public A withNewFeed(StringBuilder arg1);
    public A withNewFeed(int[] arg1,int arg2,int arg3);
    public A withNewFeed(char[] arg1);
    public A withNewFeed(StringBuffer arg1);
    public A withNewFeed(byte[] arg1,int arg2);
    public A withNewFeed(byte[] arg1);
    public A withNewFeed(char[] arg1,int arg2,int arg3);
    public A withNewFeed(byte[] arg1,int arg2,int arg3);
    public A withNewFeed(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewFeed(String arg1);
    public String getServiceAccountName();
    public A withServiceAccountName(String serviceAccountName);
    public Boolean hasServiceAccountName();
    public A withNewServiceAccountName(StringBuilder arg1);
    public A withNewServiceAccountName(int[] arg1,int arg2,int arg3);
    public A withNewServiceAccountName(char[] arg1);
    public A withNewServiceAccountName(StringBuffer arg1);
    public A withNewServiceAccountName(byte[] arg1,int arg2);
    public A withNewServiceAccountName(byte[] arg1);
    public A withNewServiceAccountName(char[] arg1,int arg2,int arg3);
    public A withNewServiceAccountName(byte[] arg1,int arg2,int arg3);
    public A withNewServiceAccountName(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewServiceAccountName(String arg1);
    
/**
 * This method has been deprecated, please use method buildSink instead.
 * @return The buildable object.
 */
@Deprecated public Destination getSink();
    public Destination buildSink();
    public A withSink(Destination sink);
    public Boolean hasSink();
    public CouchDbSourceSpecFluent.SinkNested<A> withNewSink();
    public CouchDbSourceSpecFluent.SinkNested<A> withNewSinkLike(Destination item);
    public CouchDbSourceSpecFluent.SinkNested<A> editSink();
    public CouchDbSourceSpecFluent.SinkNested<A> editOrNewSink();
    public CouchDbSourceSpecFluent.SinkNested<A> editOrNewSinkLike(Destination item);
    public interface CredentialsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectReferenceFluent<CouchDbSourceSpecFluent.CredentialsNested<N>> {

            public N and();
            public N endCredentials();    }


    public interface SinkNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DestinationFluent<CouchDbSourceSpecFluent.SinkNested<N>> {

            public N and();
            public N endSink();    }


}

==> knative-model-5.3.1-sources.jar: io/fabric8/knative/eventing/contrib/couchdb/v1alpha1/CouchDbSourceSpecFluent.java <==
package io.fabric8.knative.eventing.contrib.couchdb.v1alpha1;

import io.fabric8.knative.internal.pkg.apis.duck.v1.Destination;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationFluent;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface CouchDbSourceSpecFluent<A extends CouchDbSourceSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildCredentials instead.
 * @return The buildable object.
 */
@Deprecated public ObjectReference getCredentials();
    public ObjectReference buildCredentials();
    public A withCredentials(ObjectReference credentials);
    public Boolean hasCredentials();
    public io.fabric8.knative.eventing.contrib.couchdb.v1alpha1.CouchDbSourceSpecFluent.CredentialsNested<A> withNewCredentials();
    public io.fabric8.knative.eventing.contrib.couchdb.v1alpha1.CouchDbSourceSpecFluent.CredentialsNested<A> withNewCredentialsLike(ObjectReference item);
    public io.fabric8.knative.eventing.contrib.couchdb.v1alpha1.CouchDbSourceSpecFluent.CredentialsNested<A> editCredentials();
    public io.fabric8.knative.eventing.contrib.couchdb.v1alpha1.CouchDbSourceSpecFluent.CredentialsNested<A> editOrNewCredentials();
    public io.fabric8.knative.eventing.contrib.couchdb.v1alpha1.CouchDbSourceSpecFluent.CredentialsNested<A> editOrNewCredentialsLike(ObjectReference item);
    public String getDatabase();
    public A withDatabase(String database);
    public Boolean hasDatabase();
    public A withNewDatabase(StringBuilder arg1);
    public A withNewDatabase(int[] arg1,int arg2,int arg3);
    public A withNewDatabase(char[] arg1);
    public A withNewDatabase(StringBuffer arg1);
    public A withNewDatabase(byte[] arg1,int arg2);
    public A withNewDatabase(byte[] arg1);
    public A withNewDatabase(char[] arg1,int arg2,int arg3);
    public A withNewDatabase(byte[] arg1,int arg2,int arg3);
    public A withNewDatabase(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewDatabase(String arg1);
    public String getFeed();
    public A withFeed(String feed);
    public Boolean hasFeed();
    public A withNewFeed(StringBuilder arg1);
    public A withNewFeed(int[] arg1,int arg2,int arg3);
    public A withNewFeed(char[] arg1);
    public A withNewFeed(StringBuffer arg1);
    public A withNewFeed(byte[] arg1,int arg2);
    public A withNewFeed(byte[] arg1);
    public A withNewFeed(char[] arg1,int arg2,int arg3);
    public A withNewFeed(byte[] arg1,int arg2,int arg3);
    public A withNewFeed(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewFeed(String arg1);
    public String getServiceAccountName();
    public A withServiceAccountName(String serviceAccountName);
    public Boolean hasServiceAccountName();
    public A withNewServiceAccountName(StringBuilder arg1);
    public A withNewServiceAccountName(int[] arg1,int arg2,int arg3);
    public A withNewServiceAccountName(char[] arg1);
    public A withNewServiceAccountName(StringBuffer arg1);
    public A withNewServiceAccountName(byte[] arg1,int arg2);
    public A withNewServiceAccountName(byte[] arg1);
    public A withNewServiceAccountName(char[] arg1,int arg2,int arg3);
    public A withNewServiceAccountName(byte[] arg1,int arg2,int arg3);
    public A withNewServiceAccountName(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewServiceAccountName(String arg1);
    
/**
 * This method has been deprecated, please use method buildSink instead.
 * @return The buildable object.
 */
@Deprecated public Destination getSink();
    public Destination buildSink();
    public A withSink(Destination sink);
    public Boolean hasSink();
    public io.fabric8.knative.eventing.contrib.couchdb.v1alpha1.CouchDbSourceSpecFluent.SinkNested<A> withNewSink();
    public io.fabric8.knative.eventing.contrib.couchdb.v1alpha1.CouchDbSourceSpecFluent.SinkNested<A> withNewSinkLike(Destination item);
    public io.fabric8.knative.eventing.contrib.couchdb.v1alpha1.CouchDbSourceSpecFluent.SinkNested<A> editSink();
    public io.fabric8.knative.eventing.contrib.couchdb.v1alpha1.CouchDbSourceSpecFluent.SinkNested<A> editOrNewSink();
    public io.fabric8.knative.eventing.contrib.couchdb.v1alpha1.CouchDbSourceSpecFluent.SinkNested<A> editOrNewSinkLike(Destination item);
    public interface CredentialsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectReferenceFluent<io.fabric8.knative.eventing.contrib.couchdb.v1alpha1.CouchDbSourceSpecFluent.CredentialsNested<N>> {

            public N and();
            public N endCredentials();    }


    public interface SinkNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DestinationFluent<io.fabric8.knative.eventing.contrib.couchdb.v1alpha1.CouchDbSourceSpecFluent.SinkNested<N>> {

            public N and();
            public N endSink();    }


}
